@@ -65,11 +65,11 @@ void TreeWidget::insertTopLevelItems(int index, const QList<QTreeWidgetItem*> &i
 void TreeWidget::mousePressEvent(QMouseEvent* event)
 {
     if (event->modifiers() == Qt::ControlModifier) {
-        Q_EMIT itemControlClicked(itemAt(event->pos()));
+        Q_EMIT itemControlClicked(itemAt(event->position().toPoint()));
     }
 
     if (event->buttons() == Qt::MiddleButton) {
-        Q_EMIT itemMiddleButtonClicked(itemAt(event->pos()));
+        Q_EMIT itemMiddleButtonClicked(itemAt(event->position().toPoint()));
     }
 
     QTreeWidget::mousePressEvent(event);
